@@ -6,38 +6,9 @@ from dailycheckin import CheckIn
 
 
 def checkin_map():
-    name_map = {
-        "IQIYI": "IQIYI_COOKIE_LIST",
-        "VQQ": "VQQ_COOKIE_LIST",
-        "MGTV": "MGTV_PARAMS_LIST",
-        "KGQQ": "KGQQ_COOKIE_LIST",
-        "MUSIC163": "MUSIC163_ACCOUNT_LIST",
-        "BILIBILI": "BILIBILI_COOKIE_LIST",
-        "YOUDAO": "YOUDAO_COOKIE_LIST",
-        "FMAPP": "FMAPP_ACCOUNT_LIST",
-        "BAIDU": "BAIDU_URL_SUBMIT_LIST",
-        "ONEPLUSBBS": "ONEPLUSBBS_COOKIE_LIST",
-        "SMZDM": "SMZDM_COOKIE_LIST",
-        "TIEBA": "TIEBA_COOKIE_LIST",
-        "V2EX": "V2EX_COOKIE_LIST",
-        "WWW2NZZ": "WWW2NZZ_COOKIE_LIST",
-        "ACFUN": "ACFUN_ACCOUNT_LIST",
-        "MIMOTION": "MIMOTION_ACCOUNT_LIST",
-        "CLOUD189": "CLOUD189_ACCOUNT_LIST",
-        "POJIE": "POJIE_COOKIE_LIST",
-        "MEIZU": "MEIZU_COOKIE_LIST",
-        "PICACOMIC": "PICACOMIC_ACCOUNT_LIST",
-        "ZHIYOO": "ZHIYOO_COOKIE_LIST",
-        "WEIBO": "WEIBO_COOKIE_LIST",
-        "DUOKAN": "DUOKAN_COOKIE_LIST",
-        "CSDN": "CSDN_COOKIE_LIST",
-        "WZYD": "WZYD_DATA_LIST",
-        "WOMAIL": "WOMAIL_URL_LIST",
-        "WEATHER": "CITY_NAME_LIST",
-    }
     result = {}
     for cls in CheckIn.__subclasses__():
-        check_name = name_map.get(cls.__name__.upper(), cls.__name__.upper()).upper()
+        check_name = cls.__name__.upper()
         if check_name:
             result[check_name] = (cls.name, cls)
     return result
