@@ -27,7 +27,7 @@ class WZYD(CheckIn):
         return msg
 
     def main(self):
-        wzyd_data = self.check_item.get("wzyd_data")
+        wzyd_data = self.check_item.get("data")
         data = {k: v[0] for k, v in parse.parse_qs(wzyd_data).items()}
         try:
             user_id = data.get("userId", "")
@@ -35,14 +35,16 @@ class WZYD(CheckIn):
             print(f"获取用户信息失败: {e}")
             user_id = "未获取到用户信息"
         sign_msg = self.sign(data=data)
-        msg = f"帐号信息: {user_id}\n签到信息: {sign_msg}"
+        msg = [
+            {"name": "帐号信息", "value": user_id},
+            {"name": "签到信息", "value": sign_msg},
+        ]
+        msg = "\n".join([f"{one.get('name')}: {one.get('value')}" for one in msg])
         return msg
 
 
 if __name__ == "__main__":
-    with open(
-        os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8"
-    ) as f:
+    with open(os.path.join(os.path.dirname(os.path.dirname(__file__)), "config.json"), "r", encoding="utf-8") as f:
         datas = json.loads(f.read())
-    _check_item = datas.get("WZYD_DATA_LIST", [])[0]
+    _check_item = datas.get("WZYD", [])[0]
     print(WZYD(check_item=_check_item).main())
